@@ -32,6 +32,8 @@
  * virStoragePool:
  *
  * a virStoragePool is a private structure representing a storage pool
+ *
+ * Since: 0.4.1
  */
 typedef struct _virStoragePool virStoragePool;
 
@@ -40,53 +42,86 @@ typedef struct _virStoragePool virStoragePool;
  *
  * a virStoragePoolPtr is pointer to a virStoragePool private structure, this is the
  * type used to reference a storage pool in the API.
+ *
+ * Since: 0.4.1
  */
 typedef virStoragePool *virStoragePoolPtr;
 
 
+/**
+ * virStoragePoolState:
+ *
+ * Since: 0.4.1
+ */
 typedef enum {
-    VIR_STORAGE_POOL_INACTIVE = 0, /* Not running */
-    VIR_STORAGE_POOL_BUILDING = 1, /* Initializing pool, not available */
-    VIR_STORAGE_POOL_RUNNING = 2,  /* Running normally */
-    VIR_STORAGE_POOL_DEGRADED = 3, /* Running degraded */
-    VIR_STORAGE_POOL_INACCESSIBLE = 4, /* Running, but not accessible */
+    VIR_STORAGE_POOL_INACTIVE = 0, /* Not running (Since: 0.4.1) */
+    VIR_STORAGE_POOL_BUILDING = 1, /* Initializing pool, not available (Since: 0.4.1) */
+    VIR_STORAGE_POOL_RUNNING = 2,  /* Running normally (Since: 0.4.1) */
+    VIR_STORAGE_POOL_DEGRADED = 3, /* Running degraded (Since: 0.4.1) */
+    VIR_STORAGE_POOL_INACCESSIBLE = 4, /* Running, but not accessible (Since: 0.8.2) */
 
 # ifdef VIR_ENUM_SENTINELS
-    VIR_STORAGE_POOL_STATE_LAST
+    VIR_STORAGE_POOL_STATE_LAST /* (Since: 0.9.10) */
 # endif
 } virStoragePoolState;
 
+/**
+ * virStoragePoolBuildFlags:
+ *
+ * Since: 0.4.1
+ */
 typedef enum {
-    VIR_STORAGE_POOL_BUILD_NEW  = 0,   /* Regular build from scratch */
-    VIR_STORAGE_POOL_BUILD_REPAIR = (1 << 0), /* Repair / reinitialize */
-    VIR_STORAGE_POOL_BUILD_RESIZE = (1 << 1),  /* Extend existing pool */
-    VIR_STORAGE_POOL_BUILD_NO_OVERWRITE = (1 << 2),  /* Do not overwrite existing pool */
-    VIR_STORAGE_POOL_BUILD_OVERWRITE = (1 << 3),  /* Overwrite data */
+    VIR_STORAGE_POOL_BUILD_NEW  = 0,   /* Regular build from scratch (Since: 0.4.1) */
+    VIR_STORAGE_POOL_BUILD_REPAIR = (1 << 0), /* Repair / reinitialize (Since: 0.4.1) */
+    VIR_STORAGE_POOL_BUILD_RESIZE = (1 << 1),  /* Extend existing pool (Since: 0.4.1) */
+    VIR_STORAGE_POOL_BUILD_NO_OVERWRITE = (1 << 2),  /* Do not overwrite existing pool (Since: 0.9.5) */
+    VIR_STORAGE_POOL_BUILD_OVERWRITE = (1 << 3),  /* Overwrite data (Since: 0.9.5) */
 } virStoragePoolBuildFlags;
 
+/**
+ * virStoragePoolDeleteFlags:
+ *
+ * Since: 0.4.1
+ */
 typedef enum {
-    VIR_STORAGE_POOL_DELETE_NORMAL = 0, /* Delete metadata only    (fast) */
-    VIR_STORAGE_POOL_DELETE_ZEROED = 1 << 0,  /* Clear all data to zeros (slow) */
+    VIR_STORAGE_POOL_DELETE_NORMAL = 0, /* Delete metadata only    (fast) (Since: 0.4.1) */
+    VIR_STORAGE_POOL_DELETE_ZEROED = 1 << 0,  /* Clear all data to zeros (slow) (Since: 0.4.1) */
 } virStoragePoolDeleteFlags;
 
+/**
+ * virStoragePoolCreateFlags:
+ *
+ * Since: 1.3.1
+ */
 typedef enum {
-    /* Create the pool but do not perform pool build */
+    /* Create the pool but do not perform pool build (Since: 1.3.1) */
     VIR_STORAGE_POOL_CREATE_NORMAL = 0,
 
-    /* Create the pool and perform pool build without any flags */
+    /* Create the pool and perform pool build without any flags (Since: 1.3.1) */
     VIR_STORAGE_POOL_CREATE_WITH_BUILD = 1 << 0,
 
     /* Create the pool and perform pool build using the
      * VIR_STORAGE_POOL_BUILD_OVERWRITE flag. This is mutually
-     * exclusive to VIR_STORAGE_POOL_CREATE_WITH_BUILD_NO_OVERWRITE */
+     * exclusive to VIR_STORAGE_POOL_CREATE_WITH_BUILD_NO_OVERWRITE
+     *
+     * Since: 1.3.1
+     */
     VIR_STORAGE_POOL_CREATE_WITH_BUILD_OVERWRITE = 1 << 1,
 
     /* Create the pool and perform pool build using the
      * VIR_STORAGE_POOL_BUILD_NO_OVERWRITE flag. This is mutually
-     * exclusive to VIR_STORAGE_POOL_CREATE_WITH_BUILD_OVERWRITE */
+     * exclusive to VIR_STORAGE_POOL_CREATE_WITH_BUILD_OVERWRITE
+     *
+     * Since: 1.3.1
+     */
     VIR_STORAGE_POOL_CREATE_WITH_BUILD_NO_OVERWRITE = 1 << 2,
 } virStoragePoolCreateFlags;
 
+/**
+ * virStoragePoolInfo:
+ *
+ * Since: 0.4.1
+ */
 typedef struct _virStoragePoolInfo virStoragePoolInfo;
 
 struct _virStoragePoolInfo {
@@ -96,6 +131,11 @@ struct _virStoragePoolInfo {
     unsigned long long available;  /* Remaining free space bytes */
 };
 
+/**
+ * virStoragePoolInfoPtr:
+ *
+ * Since: 0.4.1
+ */
 typedef virStoragePoolInfo *virStoragePoolInfoPtr;
 
 
@@ -103,6 +143,8 @@ typedef virStoragePoolInfo *virStoragePoolInfoPtr;
  * virStorageVol:
  *
  * a virStorageVol is a private structure representing a storage volume
+ *
+ * Since: 0.4.1
  */
 typedef struct _virStorageVol virStorageVol;
 
@@ -111,51 +153,68 @@ typedef struct _virStorageVol virStorageVol;
  *
  * a virStorageVolPtr is pointer to a virStorageVol private structure, this is the
  * type used to reference a storage volume in the API.
+ *
+ * Since: 0.4.1
  */
 typedef virStorageVol *virStorageVolPtr;
 
 
+/**
+ * virStorageVolType:
+ *
+ * Since: 0.4.1
+ */
 typedef enum {
-    VIR_STORAGE_VOL_FILE = 0,     /* Regular file based volumes */
-    VIR_STORAGE_VOL_BLOCK = 1,    /* Block based volumes */
-    VIR_STORAGE_VOL_DIR = 2,      /* Directory-passthrough based volume */
-    VIR_STORAGE_VOL_NETWORK = 3,  /* Network volumes like RBD (RADOS Block Device) */
+    VIR_STORAGE_VOL_FILE = 0,     /* Regular file based volumes (Since: 0.4.1) */
+    VIR_STORAGE_VOL_BLOCK = 1,    /* Block based volumes (Since: 0.4.1) */
+    VIR_STORAGE_VOL_DIR = 2,      /* Directory-passthrough based volume (Since: 0.9.5) */
+    VIR_STORAGE_VOL_NETWORK = 3,  /* Network volumes like RBD (RADOS Block Device) (Since: 0.9.13) */
     VIR_STORAGE_VOL_NETDIR = 4,   /* Network accessible directory that can
-                                   * contain other network volumes */
-    VIR_STORAGE_VOL_PLOOP = 5,    /* Ploop based volumes */
+                                   * contain other network volumes (Since: 1.2.0) */
+    VIR_STORAGE_VOL_PLOOP = 5,    /* Ploop based volumes (Since: 1.3.4) */
 
 # ifdef VIR_ENUM_SENTINELS
-    VIR_STORAGE_VOL_LAST
+    VIR_STORAGE_VOL_LAST /* (Since: 0.9.10) */
 # endif
 } virStorageVolType;
 
+/**
+ * virStorageVolDeleteFlags:
+ *
+ * Since: 0.4.1
+ */
 typedef enum {
-    VIR_STORAGE_VOL_DELETE_NORMAL = 0, /* Delete metadata only    (fast) */
-    VIR_STORAGE_VOL_DELETE_ZEROED = 1 << 0,  /* Clear all data to zeros (slow) */
-    VIR_STORAGE_VOL_DELETE_WITH_SNAPSHOTS = 1 << 1, /* Force removal of volume, even if in use */
+    VIR_STORAGE_VOL_DELETE_NORMAL = 0, /* Delete metadata only    (fast) (Since: 0.4.1) */
+    VIR_STORAGE_VOL_DELETE_ZEROED = 1 << 0,  /* Clear all data to zeros (slow) (Since: 0.4.1) */
+    VIR_STORAGE_VOL_DELETE_WITH_SNAPSHOTS = 1 << 1, /* Force removal of volume, even if in use (Since: 1.2.21) */
 } virStorageVolDeleteFlags;
 
+/**
+ * virStorageVolWipeAlgorithm:
+ *
+ * Since: 0.9.10
+ */
 typedef enum {
-    VIR_STORAGE_VOL_WIPE_ALG_ZERO = 0, /* 1-pass, all zeroes */
+    VIR_STORAGE_VOL_WIPE_ALG_ZERO = 0, /* 1-pass, all zeroes (Since: 0.9.10) */
     VIR_STORAGE_VOL_WIPE_ALG_NNSA = 1, /* 4-pass  NNSA Policy Letter
-                                          NAP-14.1-C (XVI-8) */
+                                          NAP-14.1-C (XVI-8) (Since: 0.9.10) */
     VIR_STORAGE_VOL_WIPE_ALG_DOD = 2, /* 4-pass DoD 5220.22-M section
-                                         8-306 procedure */
+                                         8-306 procedure (Since: 0.9.10) */
     VIR_STORAGE_VOL_WIPE_ALG_BSI = 3, /* 9-pass method recommended by the
                                          German Center of Security in
-                                         Information Technologies */
-    VIR_STORAGE_VOL_WIPE_ALG_GUTMANN = 4, /* The canonical 35-pass sequence */
+                                         Information Technologies (Since: 0.9.10) */
+    VIR_STORAGE_VOL_WIPE_ALG_GUTMANN = 4, /* The canonical 35-pass sequence (Since: 0.9.10) */
     VIR_STORAGE_VOL_WIPE_ALG_SCHNEIER = 5, /* 7-pass method described by
                                               Bruce Schneier in "Applied
-                                              Cryptography" (1996) */
-    VIR_STORAGE_VOL_WIPE_ALG_PFITZNER7 = 6, /* 7-pass random */
+                                              Cryptography" (1996) (Since: 0.9.10) */
+    VIR_STORAGE_VOL_WIPE_ALG_PFITZNER7 = 6, /* 7-pass random data (Since: 0.9.10) */
 
-    VIR_STORAGE_VOL_WIPE_ALG_PFITZNER33 = 7, /* 33-pass random */
+    VIR_STORAGE_VOL_WIPE_ALG_PFITZNER33 = 7, /* 33-pass random data (Since: 0.9.10) */
 
-    VIR_STORAGE_VOL_WIPE_ALG_RANDOM = 8, /* 1-pass random */
+    VIR_STORAGE_VOL_WIPE_ALG_RANDOM = 8, /* 1-pass random data (Since: 0.9.10) */
 
     VIR_STORAGE_VOL_WIPE_ALG_TRIM = 9, /* 1-pass, trim all data on the
-                                          volume by using TRIM or DISCARD */
+                                          volume by using TRIM or DISCARD (Since: 1.3.2) */
 
 # ifdef VIR_ENUM_SENTINELS
     VIR_STORAGE_VOL_WIPE_ALG_LAST
@@ -163,18 +222,27 @@ typedef enum {
      * NB: this enum value will increase over time as new algorithms are
      * added to the libvirt API. It reflects the last algorithm supported
      * by this version of the libvirt API.
+     *
+     * Since: 0.9.10
      */
 # endif
 } virStorageVolWipeAlgorithm;
 
+/**
+ * virStorageVolInfoFlags:
+ *
+ * Since: 3.0.0
+ */
 typedef enum {
-    VIR_STORAGE_VOL_USE_ALLOCATION = 0,
-
-    /* Return the physical size in allocation */
-    VIR_STORAGE_VOL_GET_PHYSICAL = 1 << 0,
-
+    VIR_STORAGE_VOL_USE_ALLOCATION = 0, /* (Since: 3.0.0) */
+    VIR_STORAGE_VOL_GET_PHYSICAL = 1 << 0, /* Return the physical size in allocation (Since: 3.0.0) */
 } virStorageVolInfoFlags;
 
+/**
+ * virStorageVolInfo:
+ *
+ * Since: 0.4.1
+ */
 typedef struct _virStorageVolInfo virStorageVolInfo;
 
 struct _virStorageVolInfo {
@@ -183,10 +251,21 @@ struct _virStorageVolInfo {
     unsigned long long allocation; /* Current allocation bytes */
 };
 
+
+/**
+ * virStorageVolInfoPtr:
+ *
+ * Since: 0.4.1
+ */
 typedef virStorageVolInfo *virStorageVolInfoPtr;
 
+/**
+ * virStorageXMLFlags:
+ *
+ * Since: 0.9.13
+ */
 typedef enum {
-    VIR_STORAGE_XML_INACTIVE    = (1 << 0), /* dump inactive pool/volume information */
+    VIR_STORAGE_XML_INACTIVE    = (1 << 0), /* dump inactive pool/volume information (Since: 0.9.13) */
 } virStorageXMLFlags;
 
 /*
@@ -220,32 +299,33 @@ int                     virConnectListDefinedStoragePools(virConnectPtr conn,
  * Flags used to tune pools returned by virConnectListAllStoragePools().
  * Note that these flags come in groups; if all bits from a group are 0,
  * then that group is not used to filter results.
+ *
+ * Since: 0.10.2
  */
 typedef enum {
-    VIR_CONNECT_LIST_STORAGE_POOLS_INACTIVE      = 1 << 0,
-    VIR_CONNECT_LIST_STORAGE_POOLS_ACTIVE        = 1 << 1,
+    VIR_CONNECT_LIST_STORAGE_POOLS_INACTIVE      = 1 << 0, /* (Since: 0.10.2) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_ACTIVE        = 1 << 1, /* (Since: 0.10.2) */
 
-    VIR_CONNECT_LIST_STORAGE_POOLS_PERSISTENT    = 1 << 2,
-    VIR_CONNECT_LIST_STORAGE_POOLS_TRANSIENT     = 1 << 3,
+    VIR_CONNECT_LIST_STORAGE_POOLS_PERSISTENT    = 1 << 2, /* (Since: 0.10.2) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_TRANSIENT     = 1 << 3, /* (Since: 0.10.2) */
 
-    VIR_CONNECT_LIST_STORAGE_POOLS_AUTOSTART     = 1 << 4,
-    VIR_CONNECT_LIST_STORAGE_POOLS_NO_AUTOSTART  = 1 << 5,
+    VIR_CONNECT_LIST_STORAGE_POOLS_AUTOSTART     = 1 << 4, /* (Since: 0.10.2) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_NO_AUTOSTART  = 1 << 5, /* (Since: 0.10.2) */
 
-    /* List pools by type */
-    VIR_CONNECT_LIST_STORAGE_POOLS_DIR           = 1 << 6,
-    VIR_CONNECT_LIST_STORAGE_POOLS_FS            = 1 << 7,
-    VIR_CONNECT_LIST_STORAGE_POOLS_NETFS         = 1 << 8,
-    VIR_CONNECT_LIST_STORAGE_POOLS_LOGICAL       = 1 << 9,
-    VIR_CONNECT_LIST_STORAGE_POOLS_DISK          = 1 << 10,
-    VIR_CONNECT_LIST_STORAGE_POOLS_ISCSI         = 1 << 11,
-    VIR_CONNECT_LIST_STORAGE_POOLS_SCSI          = 1 << 12,
-    VIR_CONNECT_LIST_STORAGE_POOLS_MPATH         = 1 << 13,
-    VIR_CONNECT_LIST_STORAGE_POOLS_RBD           = 1 << 14,
-    VIR_CONNECT_LIST_STORAGE_POOLS_SHEEPDOG      = 1 << 15,
-    VIR_CONNECT_LIST_STORAGE_POOLS_GLUSTER       = 1 << 16,
-    VIR_CONNECT_LIST_STORAGE_POOLS_ZFS           = 1 << 17,
-    VIR_CONNECT_LIST_STORAGE_POOLS_VSTORAGE      = 1 << 18,
-    VIR_CONNECT_LIST_STORAGE_POOLS_ISCSI_DIRECT  = 1 << 19,
+    VIR_CONNECT_LIST_STORAGE_POOLS_DIR           = 1 << 6, /* (Since: 0.10.2) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_FS            = 1 << 7, /* (Since: 0.10.2) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_NETFS         = 1 << 8, /* (Since: 0.10.2) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_LOGICAL       = 1 << 9, /* (Since: 0.10.2) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_DISK          = 1 << 10, /* (Since: 0.10.2) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_ISCSI         = 1 << 11, /* (Since: 0.10.2) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_SCSI          = 1 << 12, /* (Since: 0.10.2) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_MPATH         = 1 << 13, /* (Since: 0.10.2) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_RBD           = 1 << 14, /* (Since: 0.10.2) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_SHEEPDOG      = 1 << 15, /* (Since: 0.10.2) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_GLUSTER       = 1 << 16, /* (Since: 1.2.1) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_ZFS           = 1 << 17, /* (Since: 1.2.8) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_VSTORAGE      = 1 << 18, /* (Since: 3.1.0) */
+    VIR_CONNECT_LIST_STORAGE_POOLS_ISCSI_DIRECT  = 1 << 19, /* (Since: 5.6.0) */
 } virConnectListAllStoragePoolsFlags;
 
 int                     virConnectListAllStoragePools(virConnectPtr conn,
@@ -271,9 +351,13 @@ virStoragePoolPtr       virStoragePoolLookupByUUIDString(virConnectPtr conn,
 virStoragePoolPtr       virStoragePoolLookupByVolume    (virStorageVolPtr vol);
 virStoragePoolPtr       virStoragePoolLookupByTargetPath(virConnectPtr conn,
                                                          const char *path);
-
+/**
+ * virStoragePoolDefineFlags:
+ *
+ * Since: 7.7.0
+ */
 typedef enum {
-    VIR_STORAGE_POOL_DEFINE_VALIDATE = 1 << 0, /* Validate the XML document against schema */
+    VIR_STORAGE_POOL_DEFINE_VALIDATE = 1 << 0, /* Validate the XML document against schema (Since: 7.7.0) */
 } virStoragePoolDefineFlags;
 
 /*
@@ -345,9 +429,15 @@ virStorageVolPtr        virStorageVolLookupByPath       (virConnectPtr conn,
 const char*             virStorageVolGetName            (virStorageVolPtr vol);
 const char*             virStorageVolGetKey             (virStorageVolPtr vol);
 
+/**
+ * virStorageVolCreateFlags:
+ *
+ * Since: 1.0.1
+ */
 typedef enum {
-    VIR_STORAGE_VOL_CREATE_PREALLOC_METADATA = 1 << 0,
-    VIR_STORAGE_VOL_CREATE_REFLINK = 1 << 1, /* perform a btrfs lightweight copy */
+    VIR_STORAGE_VOL_CREATE_PREALLOC_METADATA = 1 << 0, /* (Since: 1.0.1) */
+    VIR_STORAGE_VOL_CREATE_REFLINK = 1 << 1, /* perform a btrfs lightweight copy (Since: 1.2.13) */
+    VIR_STORAGE_VOL_CREATE_VALIDATE = 1 << 2, /* Validate the XML document against schema (Since: 8.10.0) */
 } virStorageVolCreateFlags;
 
 virStorageVolPtr        virStorageVolCreateXML          (virStoragePoolPtr pool,
@@ -357,9 +447,13 @@ virStorageVolPtr        virStorageVolCreateXMLFrom      (virStoragePoolPtr pool,
                                                          const char *xmldesc,
                                                          virStorageVolPtr clonevol,
                                                          unsigned int flags);
-
+/**
+ * virStorageVolDownloadFlags:
+ *
+ * Since: 3.4.0
+ */
 typedef enum {
-    VIR_STORAGE_VOL_DOWNLOAD_SPARSE_STREAM = 1 << 0, /* Use sparse stream */
+    VIR_STORAGE_VOL_DOWNLOAD_SPARSE_STREAM = 1 << 0, /* Use sparse stream (Since: 3.4.0) */
 } virStorageVolDownloadFlags;
 
 int                     virStorageVolDownload           (virStorageVolPtr vol,
@@ -367,8 +461,14 @@ int                     virStorageVolDownload           (virStorageVolPtr vol,
                                                          unsigned long long offset,
                                                          unsigned long long length,
                                                          unsigned int flags);
+
+/**
+ * virStorageVolUploadFlags:
+ *
+ * Since: 3.4.0
+ */
 typedef enum {
-    VIR_STORAGE_VOL_UPLOAD_SPARSE_STREAM = 1 << 0,  /* Use sparse stream */
+    VIR_STORAGE_VOL_UPLOAD_SPARSE_STREAM = 1 << 0,  /* Use sparse stream (Since: 3.4.0) */
 } virStorageVolUploadFlags;
 
 int                     virStorageVolUpload             (virStorageVolPtr vol,
@@ -396,10 +496,15 @@ char *                  virStorageVolGetXMLDesc         (virStorageVolPtr pool,
 
 char *                  virStorageVolGetPath            (virStorageVolPtr vol);
 
+/**
+ * virStorageVolResizeFlags:
+ *
+ * Since: 0.9.10
+ */
 typedef enum {
-    VIR_STORAGE_VOL_RESIZE_ALLOCATE = 1 << 0, /* force allocation of new size */
-    VIR_STORAGE_VOL_RESIZE_DELTA    = 1 << 1, /* size is relative to current */
-    VIR_STORAGE_VOL_RESIZE_SHRINK   = 1 << 2, /* allow decrease in capacity */
+    VIR_STORAGE_VOL_RESIZE_ALLOCATE = 1 << 0, /* force allocation of new size (Since: 0.9.10) */
+    VIR_STORAGE_VOL_RESIZE_DELTA    = 1 << 1, /* size is relative to current (Since: 0.9.10) */
+    VIR_STORAGE_VOL_RESIZE_SHRINK   = 1 << 2, /* allow decrease in capacity (Since: 0.9.10) */
 } virStorageVolResizeFlags;
 
 int                     virStorageVolResize             (virStorageVolPtr vol,
@@ -414,6 +519,8 @@ int virStoragePoolIsPersistent(virStoragePoolPtr pool);
  *
  * Used to cast the event specific callback into the generic one
  * for use for virConnectStoragePoolEventRegisterAny()
+ *
+ * Since: 2.0.0
  */
 # define VIR_STORAGE_POOL_EVENT_CALLBACK(cb)((virConnectStoragePoolEventGenericCallback)(cb))
 
@@ -423,10 +530,12 @@ int virStoragePoolIsPersistent(virStoragePoolPtr pool);
  * An enumeration of supported eventId parameters for
  * virConnectStoragePoolEventRegisterAny(). Each event id determines which
  * signature of callback function will be used.
+ *
+ * Since: 2.0.0
  */
 typedef enum {
-    VIR_STORAGE_POOL_EVENT_ID_LIFECYCLE = 0, /* virConnectStoragePoolEventLifecycleCallback */
-    VIR_STORAGE_POOL_EVENT_ID_REFRESH = 1, /* virConnectStoragePoolEventGenericCallback */
+    VIR_STORAGE_POOL_EVENT_ID_LIFECYCLE = 0, /* virConnectStoragePoolEventLifecycleCallback (Since: 2.0.0) */
+    VIR_STORAGE_POOL_EVENT_ID_REFRESH = 1, /* virConnectStoragePoolEventGenericCallback (Since: 2.0.0) */
 
 # ifdef VIR_ENUM_SENTINELS
     VIR_STORAGE_POOL_EVENT_ID_LAST
@@ -434,6 +543,8 @@ typedef enum {
      * NB: this enum value will increase over time as new events are
      * added to the libvirt API. It reflects the last event ID supported
      * by this version of the libvirt API.
+     *
+     * Since: 2.0.0
      */
 # endif
 } virStoragePoolEventID;
@@ -449,6 +560,8 @@ typedef enum {
  * have a customization with extra parameters, often with @opaque being
  * passed in a different parameter position; use
  * VIR_STORAGE_POOL_EVENT_CALLBACK() when registering an appropriate handler.
+ *
+ * Since: 2.0.0
  */
 typedef void (*virConnectStoragePoolEventGenericCallback)(virConnectPtr conn,
                                                           virStoragePoolPtr pool,
@@ -470,17 +583,19 @@ int virConnectStoragePoolEventDeregisterAny(virConnectPtr conn,
  *
  * a virStoragePoolEventLifecycleType is emitted during storage pool
  * lifecycle events
+ *
+ * Since: 2.0.0
  */
 typedef enum {
-    VIR_STORAGE_POOL_EVENT_DEFINED = 0,
-    VIR_STORAGE_POOL_EVENT_UNDEFINED = 1,
-    VIR_STORAGE_POOL_EVENT_STARTED = 2,
-    VIR_STORAGE_POOL_EVENT_STOPPED = 3,
-    VIR_STORAGE_POOL_EVENT_CREATED = 4,
-    VIR_STORAGE_POOL_EVENT_DELETED = 5,
+    VIR_STORAGE_POOL_EVENT_DEFINED = 0, /* (Since: 2.0.0) */
+    VIR_STORAGE_POOL_EVENT_UNDEFINED = 1, /* (Since: 2.0.0) */
+    VIR_STORAGE_POOL_EVENT_STARTED = 2, /* (Since: 2.0.0) */
+    VIR_STORAGE_POOL_EVENT_STOPPED = 3, /* (Since: 2.0.0) */
+    VIR_STORAGE_POOL_EVENT_CREATED = 4, /* (Since: 3.8.0) */
+    VIR_STORAGE_POOL_EVENT_DELETED = 5, /* (Since: 3.8.0) */
 
 # ifdef VIR_ENUM_SENTINELS
-    VIR_STORAGE_POOL_EVENT_LAST
+    VIR_STORAGE_POOL_EVENT_LAST /* (Since: 2.0.0) */
 # endif
 } virStoragePoolEventLifecycleType;
 
@@ -498,6 +613,8 @@ typedef enum {
  * The callback signature to use when registering for an event of type
  * VIR_STORAGE_POOL_EVENT_ID_LIFECYCLE with
  * virConnectStoragePoolEventRegisterAny()
+ *
+ * Since: 2.0.0
  */
 typedef void (*virConnectStoragePoolEventLifecycleCallback)(virConnectPtr conn,
                                                             virStoragePoolPtr pool,
