@@ -2,6 +2,7 @@
  * bhyve_conf.c: bhyve config file
  *
  * Copyright (C) 2017 Roman Bogorodskiy
+ * Copyright (C) 2025 The FreeBSD Foundation
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -57,6 +58,11 @@ virBhyveDriverConfigNew(void)
         return NULL;
 
     cfg->firmwareDir = g_strdup(DATADIR "/uefi-firmware");
+    cfg->libDir = g_strdup_printf("%s/lib/libvirt/bhyve", LOCALSTATEDIR);
+    cfg->nvramDir = g_strdup_printf("%s/nvram", cfg->libDir);
+
+    cfg->bhyveloadTimeout = 300;
+    cfg->bhyveloadTimeoutKill = 15;
 
     return cfg;
 }
@@ -79,6 +85,14 @@ virBhyveLoadDriverConfig(struct _virBhyveDriverConfig *cfg,
                               &cfg->firmwareDir) < 0)
         return -1;
 
+    if (virConfGetValueInt(conf, "bhyveload_timeout",
+                           &cfg->bhyveloadTimeout) < 0)
+        return -1;
+
+    if (virConfGetValueInt(conf, "bhyveload_timeout_kill",
+                           &cfg->bhyveloadTimeoutKill) < 0)
+        return -1;
+
     return 0;
 }
 
@@ -95,6 +109,8 @@ virBhyveDriverConfigDispose(void *obj)
     struct _virBhyveDriverConfig *cfg = obj;
 
     g_free(cfg->firmwareDir);
+    g_free(cfg->libDir);
+    g_free(cfg->nvramDir);
 }
 
 void
