@@ -26,13 +26,26 @@
 int virCHProcessStart(virCHDriver *driver,
                       virDomainObj *vm,
                       virDomainRunningReason reason);
+
+typedef enum {
+    VIR_CH_PROCESS_STOP_FORCE = 1 << 0,
+} virCHProcessStopFlags;
+
 int virCHProcessStop(virCHDriver *driver,
                      virDomainObj *vm,
-                     virDomainShutoffReason reason);
-
-int virCHProcessSetupVcpu(virDomainObj *vm,
-                          unsigned int vcpuid);
+                     virDomainShutoffReason reason,
+                     unsigned int flags);
 
 int virCHProcessStartRestore(virCHDriver *driver,
                          virDomainObj *vm,
                          const char *from);
+
+int virCHProcessUpdateInfo(virDomainObj *vm);
+
+int
+chProcessAddNetworkDevice(virCHDriver *driver,
+                          virCHMonitor *mon,
+                          virDomainDef *vmdef,
+                          virDomainNetDef *net,
+                          int **nicindexes,
+                          size_t *nnicindexes);
