@@ -1663,14 +1663,14 @@ static int
 virDomainVirtioSerialAddrNext(virDomainDef *def,
                               virDomainVirtioSerialAddrSet *addrs,
                               virDomainDeviceVirtioSerialAddress *addr,
-                              bool allowZero)
+                              bool allowPortZero)
 {
     ssize_t port, startPort = 0;
     ssize_t i;
     unsigned int controller;
 
-    /* port number 0 is reserved for virtconsoles */
-    if (allowZero)
+    /* port number 0 is reserved for the first virtconsole */
+    if (allowPortZero)
         startPort = -1;
 
     if (addrs->ncontrollers == 0) {
@@ -1717,12 +1717,17 @@ virDomainVirtioSerialAddrNext(virDomainDef *def,
 
 static int
 virDomainVirtioSerialAddrNextFromController(virDomainVirtioSerialAddrSet *addrs,
-                                            virDomainDeviceVirtioSerialAddress *addr)
+                                            virDomainDeviceVirtioSerialAddress *addr,
+                                            bool allowPortZero)
 {
+    ssize_t startPort = 0;
     ssize_t port;
     ssize_t i;
     virBitmap *map;
 
+    if (allowPortZero)
+        startPort = -1;
+
     i = virDomainVirtioSerialAddrFindController(addrs, addr->controller);
     if (i < 0) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
@@ -1732,7 +1737,7 @@ virDomainVirtioSerialAddrNextFromController(virDomainVirtioSerialAddrSet *addrs,
     }
 
     map = addrs->controllers[i]->ports;
-    if ((port = virBitmapNextClearBit(map, 0)) <= 0) {
+    if ((port = virBitmapNextClearBit(map, startPort)) < 0) {
         virReportError(VIR_ERR_XML_ERROR,
                        _("Unable to find a free port on virtio-serial controller %1$u"),
                        addr->controller);
@@ -1750,21 +1755,41 @@ static int ATTRIBUTE_NONNULL(2) ATTRIBUTE_NONNULL(3)
 virDomainVirtioSerialAddrAssign(virDomainDef *def,
                                 virDomainVirtioSerialAddrSet *addrs,
                                 virDomainDeviceInfo *info,
-                                bool allowZero,
+                                bool allowPortZero,
                                 bool portOnly)
 {
     virDomainDeviceInfo nfo = { 0 };
-    virDomainDeviceInfo *ptr = allowZero ? &nfo : info;
+    virDomainDeviceInfo *ptr = allowPortZero ? &nfo : info;
+    virBitmap *map;
+    ssize_t i;
 
     ptr->type = VIR_DOMAIN_DEVICE_ADDRESS_TYPE_VIRTIO_SERIAL;
+    ptr->addr.vioserial.controller = info->addr.vioserial.controller;
 
     if (portOnly) {
         if (virDomainVirtioSerialAddrNextFromController(addrs,
-                                                        &ptr->addr.vioserial) < 0)
+                                                        &ptr->addr.vioserial,
+                                                        allowPortZero) < 0)
             return -1;
+
+        if (ptr == &nfo) {
+            /* pass the vioserial data back into info as info is used
+             * later for port assignment */
+            info->addr.vioserial = ptr->addr.vioserial;
+
+            /* if the next available port from the controller is zero,
+             * let's reserve it in the map and return */
+            if (ptr->addr.vioserial.port == 0) {
+                i = virDomainVirtioSerialAddrFindController(addrs, ptr->addr.vioserial.controller);
+                map = addrs->controllers[i]->ports;
+                ignore_value(virBitmapSetBit(map, 0));
+                return 0;
+            }
+        }
+
     } else {
         if (virDomainVirtioSerialAddrNext(def, addrs, &ptr->addr.vioserial,
-                                          allowZero) < 0)
+                                          allowPortZero) < 0)
             return -1;
     }
 
@@ -1783,20 +1808,20 @@ int
 virDomainVirtioSerialAddrAutoAssignFromCache(virDomainDef *def,
                                              virDomainVirtioSerialAddrSet *addrs,
                                              virDomainDeviceInfo *info,
-                                             bool allowZero)
+                                             bool allowPortZero)
 {
     bool portOnly = info->type == VIR_DOMAIN_DEVICE_ADDRESS_TYPE_VIRTIO_SERIAL;
     if (info->type == VIR_DOMAIN_DEVICE_ADDRESS_TYPE_VIRTIO_SERIAL &&
         info->addr.vioserial.port)
         return virDomainVirtioSerialAddrReserve(NULL, NULL, info, addrs);
     else
-        return virDomainVirtioSerialAddrAssign(def, addrs, info, allowZero, portOnly);
+        return virDomainVirtioSerialAddrAssign(def, addrs, info, allowPortZero, portOnly);
 }
 
 int
 virDomainVirtioSerialAddrAutoAssign(virDomainDef *def,
                                     virDomainDeviceInfo *info,
-                                    bool allowZero)
+                                    bool allowPortZero)
 {
     virDomainVirtioSerialAddrSet *addrs = NULL;
     int ret = -1;
@@ -1804,7 +1829,7 @@ virDomainVirtioSerialAddrAutoAssign(virDomainDef *def,
     if (!(addrs = virDomainVirtioSerialAddrSetCreateFromDomain(def)))
         goto cleanup;
 
-    if (virDomainVirtioSerialAddrAutoAssignFromCache(def, addrs, info, allowZero) < 0)
+    if (virDomainVirtioSerialAddrAutoAssignFromCache(def, addrs, info, allowPortZero) < 0)
         goto cleanup;
 
     ret = 0;
