@@ -44,6 +44,7 @@ typedef enum {
     VIR_STORAGE_TYPE_NVME,
     VIR_STORAGE_TYPE_VHOST_USER,
     VIR_STORAGE_TYPE_VHOST_VDPA,
+    VIR_STORAGE_TYPE_CTL,
 
     VIR_STORAGE_TYPE_LAST
 } virStorageType;
@@ -141,6 +142,7 @@ typedef enum {
     VIR_STORAGE_NET_HOST_TRANS_TCP,
     VIR_STORAGE_NET_HOST_TRANS_UNIX,
     VIR_STORAGE_NET_HOST_TRANS_RDMA,
+    VIR_STORAGE_NET_HOST_TRANS_FD,
 
     VIR_STORAGE_NET_HOST_TRANS_LAST
 } virStorageNetHostTransport;
@@ -154,6 +156,9 @@ struct _virStorageNetHostDef {
     unsigned int port;
     virStorageNetHostTransport transport;
     char *socket;  /* path to unix socket */
+
+    char *fdgroup;
+    char *qemu_fdname; /* name used with 'getfd' to pass to qemu - internal */
 };
 
 
@@ -297,8 +302,7 @@ struct _virStorageSource {
     virStorageType type;
     char *path;
     char *fdgroup; /* name of group of file descriptors the user wishes to use instead of 'path' */
-    int protocol; /* virStorageNetProtocol */
-    char *volume; /* volume name for remote storage */
+    virStorageNetProtocol protocol;
     char *snapshot; /* for storage systems supporting internal snapshots */
     char *configFile; /* some storage systems use config file as part of
                          the source definition */
@@ -392,6 +396,7 @@ struct _virStorageSource {
      * certificate directory with listen and verify bools. */
     char *tlsAlias;
     char *tlsCertdir;
+    char *tlsPriority;
 
     /* TLS hostname override */
     char *tlsHostname;
@@ -445,6 +450,12 @@ struct _virStorageSource {
      * to do this decision.
      */
     bool seclabelSkipRemember;
+
+    /* Last instance of hypervisor originated I/O error message and timestamp.
+     * The error stored here is not designed to be stable. The message
+     * is also not copied via virStorageSourceCopy */
+    char *ioerror_timestamp;
+    char *ioerror_message;
 };
 
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(virStorageSource, virObjectUnref);
@@ -496,9 +507,6 @@ virSecurityDeviceLabelDef *
 virStorageSourceGetSecurityLabelDef(virStorageSource *src,
                                     const char *model);
 
-void
-virStorageNetHostDefClear(virStorageNetHostDef *def);
-
 void
 virStorageNetHostDefFree(size_t nhosts,
                          virStorageNetHostDef *hosts);
@@ -590,3 +598,10 @@ void
 virStorageSourceInitiatorClear(virStorageSourceInitiatorDef *initiator);
 
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(virStorageAuthDef, virStorageAuthDefFree);
+
+int
+virStorageSourceNetworkProtocolPathSplit(const char *path,
+                                         virStorageNetProtocol protocol,
+                                         char **pool,
+                                         char **namespace,
+                                         char **image);
