@@ -25,10 +25,9 @@
 #include "domain_conf.h"
 
 typedef struct _virChrdevs virChrdevs;
-typedef virChrdevs *virChrdevsPtr;
 
-virChrdevsPtr virChrdevAlloc(void);
-void virChrdevFree(virChrdevsPtr devs);
+virChrdevs *virChrdevAlloc(void);
+void virChrdevFree(virChrdevs *devs);
 
-int virChrdevOpen(virChrdevsPtr devs, virDomainChrSourceDefPtr source,
+int virChrdevOpen(virChrdevs *devs, virDomainChrSourceDef *source,
                   virStreamPtr st, bool force);
