@@ -23,8 +23,6 @@
 #include <config.h>
 
 #include "virbuffer.h"
-#include "viralloc.h"
-#include "viruuid.h"
 #include "esx_vi_methods.h"
 #include "esx_util.h"
 
@@ -106,7 +104,7 @@
         int result = -1; \
         const char *methodName = #_name; \
         g_auto(virBuffer) buffer = VIR_BUFFER_INITIALIZER; \
-        char *request = NULL; \
+        g_autofree char *request = NULL; \
         esxVI_Response *response = NULL; \
  \
         ESX_VI__METHOD__PARAMETER__THIS__##_this_from_service \
@@ -136,7 +134,6 @@
         result = 0; \
  \
       cleanup: \
-        VIR_FREE(request); \
         esxVI_Response_Free(&response); \
  \
         return result; \
