@@ -1512,11 +1512,12 @@ esxVI_DateTime_ConvertToCalendarTime(esxVI_DateTime *dateTime,
         }
 
         /* parse timezone offset if present. if missing assume UTC */
-        if (*tmp == '+' || *tmp == '-') {
-            tz = g_time_zone_new(tmp);
-        } else if (STREQ(tmp, "Z")) {
+        if (STREQ(tmp, "Z"))
             tz = g_time_zone_new_utc();
-        } else {
+
+        if (*tmp == '+' || *tmp == '-')
+            tz = g_time_zone_new_identifier(tmp);
+        if (!tz) {
             virReportError(VIR_ERR_INTERNAL_ERROR,
                            _("xsd:dateTime value '%1$s' has unexpected format"),
                            dateTime->value);
