@@ -20,35 +20,9 @@
 
 #pragma once
 
-#define FUSE_USE_VERSION 26
 
-#if WITH_FUSE
-# include <fuse.h>
-#endif
+#include "virconftypes.h"
 
-#include "lxc_conf.h"
-
-struct virLXCMeminfo {
-    unsigned long long memtotal;
-    unsigned long long memusage;
-    unsigned long long cached;
-    unsigned long long active_anon;
-    unsigned long long inactive_anon;
-    unsigned long long active_file;
-    unsigned long long inactive_file;
-    unsigned long long unevictable;
-    unsigned long long swaptotal;
-    unsigned long long swapusage;
-};
-
-struct virLXCFuse {
-    virDomainDef *def;
-    virThread thread;
-    char *mountpoint;
-    struct fuse *fuse;
-    struct fuse_chan *ch;
-    virMutex lock;
-};
 typedef struct virLXCFuse virLXCFuse;
 
 int lxcSetupFuse(struct virLXCFuse **f, virDomainDef *def);
