@@ -67,8 +67,7 @@ lxcCreateFSDef(int type,
 
     def->type = type;
     def->accessmode = VIR_DOMAIN_FS_ACCESSMODE_PASSTHROUGH;
-    if (src)
-        def->src->path = g_strdup(src);
+    def->src->path = g_strdup(src);
     def->dst = g_strdup(dst);
     def->readonly = readonly;
     def->usage = usage;
@@ -378,10 +377,6 @@ static virDomainHostdevDef *
 lxcCreateHostdevDef(const char *data)
 {
     virDomainHostdevDef *hostdev = virDomainHostdevDefNew();
-
-    if (!hostdev)
-        return NULL;
-
     hostdev->mode = VIR_DOMAIN_HOSTDEV_MODE_CAPABILITIES;
     hostdev->source.caps.type = VIR_DOMAIN_HOSTDEV_CAPS_TYPE_NET;
     hostdev->source.caps.u.net.ifname = g_strdup(data);
@@ -1126,8 +1121,7 @@ lxcParseConfigString(const char *config,
     if (virConfGetValue(properties, "lxc.mount.fstab") ||
         virConfGetValue(properties, "lxc.mount")) {
         virReportError(VIR_ERR_ARGUMENT_UNSUPPORTED, "%s",
-                       _("lxc.mount.fstab or lxc.mount found, use "
-                         "lxc.mount.entry lines instead"));
+                       _("lxc.mount.fstab or lxc.mount found, use lxc.mount.entry lines instead"));
         return NULL;
     }
 
