@@ -22,21 +22,19 @@
 #pragma once
 
 #include "internal.h"
-#include "domain_conf.h"
-#include "vircommand.h"
 #include "virdnsmasq.h"
 #include "virnetworkobj.h"
 
-virNetworkXMLOptionPtr
+virNetworkXMLOption *
 networkDnsmasqCreateXMLConf(void);
 
 int
 networkRegister(void);
 
 int
-networkDnsmasqConfContents(virNetworkObjPtr obj,
+networkDnsmasqConfContents(virNetworkObj *obj,
                            const char *pidfile,
                            char **configstr,
                            char **hostsfilestr,
                            dnsmasqContext *dctx,
-                           dnsmasqCapsPtr caps);
+                           dnsmasqCaps *caps);
