@@ -27,6 +27,7 @@
 #include "qemu_checkpoint.h"
 #include "qemu_command.h"
 #include "qemu_security.h"
+#include "qemu_process.h"
 
 #include "storage_source.h"
 #include "storage_source_conf.h"
@@ -86,8 +87,10 @@ qemuBackupPrepare(virDomainBackupDef *def)
             /* TODO: Do we need to mess with selinux? */
             break;
 
-        case VIR_STORAGE_NET_HOST_TRANS_RDMA:
         case VIR_STORAGE_NET_HOST_TRANS_FD:
+            break;
+
+        case VIR_STORAGE_NET_HOST_TRANS_RDMA:
         case VIR_STORAGE_NET_HOST_TRANS_LAST:
             virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
                            _("unexpected transport in <domainbackup>"));
@@ -557,6 +560,8 @@ qemuBackupJobTerminate(virDomainObj *vm,
 {
     qemuDomainObjPrivate *priv = vm->privateData;
     g_autoptr(virQEMUDriverConfig) cfg = NULL;
+    /* some flags need to be probed after the private data is freed */
+    unsigned int apiFlags = priv->backup->apiFlags;
     size_t i;
 
     for (i = 0; i < priv->backup->ndisks; i++) {
@@ -614,13 +619,30 @@ qemuBackupJobTerminate(virDomainObj *vm,
         vm->job->completed->status = jobstatus;
         vm->job->completed->errmsg = g_strdup(priv->backup->errmsg);
 
-        qemuDomainEventEmitJobCompleted(priv->driver, vm);
+        qemuDomainEventEmitJobCompleted(vm);
     }
 
     g_clear_pointer(&priv->backup, virDomainBackupDefFree);
 
     if (vm->job->asyncJob == VIR_ASYNC_JOB_BACKUP)
         virDomainObjEndAsyncJob(vm);
+
+    /* Users can request that the VM is preserved after a guest OS shutdown for
+     * the duration of the backup. This is the place where we need to check if
+     * this happened and optionally terminate the VM if the guest OS is still
+     * shut down */
+    if (apiFlags & VIR_DOMAIN_BACKUP_BEGIN_PRESERVE_SHUTDOWN_DOMAIN) {
+        int reason = -1;
+        virDomainState state = virDomainObjGetState(vm, &reason);
+
+        VIR_DEBUG("state: '%u', reason:'%d'", state, reason);
+
+        if (state == VIR_DOMAIN_SHUTDOWN ||
+            (state == VIR_DOMAIN_PAUSED && reason == VIR_DOMAIN_PAUSED_SHUTTING_DOWN)) {
+            VIR_DEBUG("backup job finished terminating the previously shutdown VM");
+            ignore_value(qemuProcessShutdownOrReboot(vm));
+        }
+    }
 }
 
 
@@ -726,8 +748,9 @@ qemuBackupBeginPrepareTLS(virDomainObj *vm,
     }
 
     if (qemuBuildTLSx509BackendProps(cfg->backupTLSx509certdir, true,
-                                     cfg->backupTLSx509verify, tlsObjAlias,
-                                     tlsKeySecretAlias,
+                                     cfg->backupTLSx509verify,
+                                     cfg->backupTLSpriority,
+                                     tlsObjAlias, tlsKeySecretAlias,
                                      tlsProps) < 0)
         return -1;
 
@@ -763,7 +786,8 @@ qemuBackupBegin(virDomainObj *vm,
     int ret = -1;
     g_autoptr(qemuFDPassDirect) fdpass = NULL;
 
-    virCheckFlags(VIR_DOMAIN_BACKUP_BEGIN_REUSE_EXTERNAL, -1);
+    virCheckFlags(VIR_DOMAIN_BACKUP_BEGIN_REUSE_EXTERNAL |
+                  VIR_DOMAIN_BACKUP_BEGIN_PRESERVE_SHUTDOWN_DOMAIN, -1);
 
     if (!(def = virDomainBackupDefParseString(backupXML, priv->driver->xmlopt, 0)))
         return -1;
@@ -820,6 +844,9 @@ qemuBackupBegin(virDomainObj *vm,
     if (qemuBackupBeginPrepareTLS(vm, cfg, def, &tlsProps, &tlsSecretProps) < 0)
         goto endjob;
 
+    if (qemuBlockNodesEnsureActive(vm, VIR_ASYNC_JOB_BACKUP) < 0)
+        goto endjob;
+
     actions = virJSONValueNewArray();
 
     /* The 'chk' checkpoint must be rolled back if the transaction command
@@ -975,6 +1002,33 @@ qemuBackupGetXMLDesc(virDomainObj *vm,
 }
 
 
+void
+qemuBackupNotifyBlockjobEndStopNBD(virDomainObj *vm,
+                                   int asyncJob)
+{
+    qemuDomainObjPrivate *priv = vm->privateData;
+    virDomainBackupDef *backup = priv->backup;
+
+    VIR_DEBUG("vm: '%s'", vm->def->name);
+
+    if (!backup ||
+        backup->type != VIR_DOMAIN_BACKUP_TYPE_PULL ||
+        backup->nbdStopped)
+        return;
+
+    if (qemuDomainObjEnterMonitorAsync(vm, asyncJob) < 0)
+        return;
+    ignore_value(qemuMonitorNBDServerStop(priv->mon));
+    if (backup->tlsAlias)
+        ignore_value(qemuMonitorDelObject(priv->mon, backup->tlsAlias, false));
+    if (backup->tlsSecretAlias)
+        ignore_value(qemuMonitorDelObject(priv->mon, backup->tlsSecretAlias, false));
+    qemuDomainObjExitMonitor(vm);
+
+    backup->nbdStopped = true;
+}
+
+
 void
 qemuBackupNotifyBlockjobEnd(virDomainObj *vm,
                             const char *diskdst,
@@ -999,17 +1053,8 @@ qemuBackupNotifyBlockjobEnd(virDomainObj *vm,
     if (!backup)
         return;
 
+    /* update the final statistics with the current job's data */
     if (backup->type == VIR_DOMAIN_BACKUP_TYPE_PULL) {
-        if (qemuDomainObjEnterMonitorAsync(vm, asyncJob) < 0)
-            return;
-        ignore_value(qemuMonitorNBDServerStop(priv->mon));
-        if (backup->tlsAlias)
-            ignore_value(qemuMonitorDelObject(priv->mon, backup->tlsAlias, false));
-        if (backup->tlsSecretAlias)
-            ignore_value(qemuMonitorDelObject(priv->mon, backup->tlsSecretAlias, false));
-        qemuDomainObjExitMonitor(vm);
-
-        /* update the final statistics with the current job's data */
         backup->pull_tmp_used += cur;
         backup->pull_tmp_total += end;
     } else {
