@@ -43,7 +43,6 @@ VIR_ENUM_DECL(qemuSoundCodec);
 virCommand *
 qemuBuildCommandLine(virDomainObj *vm,
                      const char *migrateURI,
-                     virDomainMomentObj *snapshot,
                      virNetDevVPortProfileOp vmop,
                      size_t *nnicindexes,
                      int **nicindexes);
@@ -68,6 +67,7 @@ int
 qemuBuildTLSx509BackendProps(const char *tlspath,
                              bool isListen,
                              bool verifypeer,
+                             const char *priority,
                              const char *alias,
                              const char *secalias,
                              virJSONValue **propsret);
@@ -75,7 +75,7 @@ qemuBuildTLSx509BackendProps(const char *tlspath,
 /* Open a UNIX socket for chardev FD passing */
 int
 qemuOpenChrChardevUNIXSocket(const virDomainChrSourceDef *dev)
-    G_NO_INLINE;
+    ATTRIBUTE_MOCKABLE;
 
 virJSONValue *
 qemuBuildChrDeviceProps(const virDomainDef *vmdef,
@@ -130,6 +130,11 @@ qemuBuildThrottleFiltersAttachPrepareBlockdev(virDomainDiskDef *disk);
 qemuBlockThrottleFiltersData *
 qemuBuildThrottleFiltersDetachPrepareBlockdev(virDomainDiskDef *disk);
 
+int
+qemuBuildDiskBusProps(const virDomainDef *def,
+                      const virDomainDiskDef *disk,
+                      virJSONValue **propsRet);
+
 virJSONValue *
 qemuBuildDiskDeviceProps(const virDomainDef *def,
                          virDomainDiskDef *disk,
@@ -270,7 +275,7 @@ int
 qemuBuildTPMOpenBackendFDs(const char *tpmdev,
                            int *tpmfd,
                            int *cancelfd)
-    ATTRIBUTE_NONNULL(1) ATTRIBUTE_NONNULL(2) ATTRIBUTE_NONNULL(3) G_NO_INLINE;
+    ATTRIBUTE_NONNULL(1) ATTRIBUTE_NONNULL(2) ATTRIBUTE_NONNULL(3) ATTRIBUTE_MOCKABLE;
 
 const char *
 qemuAudioDriverTypeToString(virDomainAudioType type);
@@ -279,4 +284,4 @@ qemuAudioDriverTypeFromString(const char *str);
 
 int
 qemuVDPAConnect(const char *devicepath)
-    G_NO_INLINE;
+    ATTRIBUTE_MOCKABLE;
