@@ -81,6 +81,11 @@ VIR_ENUM_IMPL(virQEMUSchedCore,
               "emulator",
               "full");
 
+VIR_ENUM_IMPL(virQEMUDeprecatedFeatures,
+              QEMU_DEPRECATED_FEATURES_LAST,
+              "off",
+              "on",
+              "none");
 
 static virClass *virQEMUDriverConfigClass;
 static void virQEMUDriverConfigDispose(void *obj);
@@ -320,15 +325,15 @@ virQEMUDriverConfig *virQEMUDriverConfigNew(bool privileged,
          *
          * XXX, or query if libvirt-guests.service is enabled perhaps ?
          */
-        cfg->autoShutdownTrySave = VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_NONE;
-        cfg->autoShutdownTryShutdown = VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_NONE;
-        cfg->autoShutdownPoweroff = VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_NONE;
+        cfg->autoShutdown.trySave = VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_NONE;
+        cfg->autoShutdown.tryShutdown = VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_NONE;
+        cfg->autoShutdown.poweroff = VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_NONE;
     } else {
-        cfg->autoShutdownTrySave = VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_PERSISTENT;
-        cfg->autoShutdownTryShutdown = VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_ALL;
-        cfg->autoShutdownPoweroff = VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_ALL;
+        cfg->autoShutdown.trySave = VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_PERSISTENT;
+        cfg->autoShutdown.tryShutdown = VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_ALL;
+        cfg->autoShutdown.poweroff = VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_ALL;
     }
-    cfg->autoShutdownRestore = true;
+    cfg->autoShutdown.autoRestore = true;
 
     return g_steal_pointer(&cfg);
 }
@@ -385,9 +390,6 @@ static void virQEMUDriverConfigDispose(void *obj)
     g_free(cfg->chardevTLSx509certdir);
     g_free(cfg->chardevTLSx509secretUUID);
 
-    g_free(cfg->vxhsTLSx509certdir);
-    g_free(cfg->vxhsTLSx509secretUUID);
-
     g_free(cfg->nbdTLSx509certdir);
     g_free(cfg->nbdTLSx509secretUUID);
 
@@ -457,6 +459,9 @@ virQEMUDriverConfigLoadDefaultTLSEntry(virQEMUDriverConfig *cfg,
     if (virConfGetValueString(conf, "default_tls_x509_secret_uuid",
                               &cfg->defaultTLSx509secretUUID) < 0)
         return -1;
+    if (virConfGetValueString(conf, "default_tls_priority",
+                              &cfg->defaultTLSpriority) < 0)
+        return -1;
 
     return 0;
 }
@@ -553,8 +558,6 @@ virQEMUDriverConfigLoadSpecificTLSEntry(virQEMUDriverConfig *cfg,
 {
     int rv;
 
-    if (virConfGetValueBool(conf, "vxhs_tls", &cfg->vxhsTLS) < 0)
-        return -1;
     if (virConfGetValueBool(conf, "nbd_tls", &cfg->nbdTLS) < 0)
         return -1;
     if (virConfGetValueBool(conf, "chardev_tls", &cfg->chardevTLS) < 0)
@@ -571,6 +574,9 @@ virQEMUDriverConfigLoadSpecificTLSEntry(virQEMUDriverConfig *cfg,
                                   #val "_tls_x509_secret_uuid", \
                                   &cfg->val## TLSx509secretUUID) < 0) \
             return -1; \
+        if ((rv = virConfGetValueString(conf, #val "_tls_priority", \
+                                        &cfg->val## TLSpriority)) < 0) \
+            return -1; \
     } while (0)
 
 #define GET_CONFIG_TLS_CERTINFO_SERVER(val) \
@@ -591,8 +597,6 @@ virQEMUDriverConfigLoadSpecificTLSEntry(virQEMUDriverConfig *cfg,
     GET_CONFIG_TLS_CERTINFO_COMMON(backup);
     GET_CONFIG_TLS_CERTINFO_SERVER(backup);
 
-    GET_CONFIG_TLS_CERTINFO_COMMON(vxhs);
-
     GET_CONFIG_TLS_CERTINFO_COMMON(nbd);
 
 #undef GET_CONFIG_TLS_CERTINFO_COMMON
@@ -682,29 +686,47 @@ virQEMUDriverConfigLoadSaveEntry(virQEMUDriverConfig *cfg,
 
     if (virConfGetValueString(conf, "save_image_format", &savestr) < 0)
         return -1;
-    if (savestr && (cfg->saveImageFormat = qemuSaveFormatTypeFromString(savestr)) < 0) {
-        virReportError(VIR_ERR_CONFIG_UNSUPPORTED,
-                       _("Invalid save_image_format '%1$s'"),
-                       savestr);
-        return -1;
+    if (savestr) {
+        int formatVal;
+
+        if ((formatVal = qemuSaveFormatTypeFromString(savestr)) < 0) {
+            virReportError(VIR_ERR_CONFIG_UNSUPPORTED,
+                           _("Invalid save_image_format '%1$s'"),
+                           savestr);
+            return -1;
+        }
+
+        cfg->saveImageFormat = formatVal;
     }
 
     if (virConfGetValueString(conf, "dump_image_format", &dumpstr) < 0)
         return -1;
-    if (dumpstr && (cfg->dumpImageFormat = qemuSaveFormatTypeFromString(dumpstr)) < 0) {
-        virReportError(VIR_ERR_CONFIG_UNSUPPORTED,
-                       _("Invalid dump_image_format '%1$s'"),
-                       dumpstr);
-        return -1;
+    if (dumpstr) {
+        int formatVal;
+
+        if ((formatVal = qemuSaveFormatTypeFromString(dumpstr)) < 0) {
+            virReportError(VIR_ERR_CONFIG_UNSUPPORTED,
+                           _("Invalid dump_image_format '%1$s'"),
+                           dumpstr);
+            return -1;
+        }
+
+        cfg->dumpImageFormat = formatVal;
     }
 
     if (virConfGetValueString(conf, "snapshot_image_format", &snapstr) < 0)
         return -1;
-    if (snapstr && (cfg->snapshotImageFormat = qemuSaveFormatTypeFromString(snapstr)) < 0) {
-        virReportError(VIR_ERR_CONFIG_UNSUPPORTED,
-                       _("Invalid snapshot_image_format '%1$s'"),
-                       snapstr);
-        return -1;
+    if (snapstr) {
+        int formatVal;
+
+        if ((formatVal = qemuSaveFormatTypeFromString(snapstr)) < 0) {
+            virReportError(VIR_ERR_CONFIG_UNSUPPORTED,
+                           _("Invalid snapshot_image_format '%1$s'"),
+                           snapstr);
+            return -1;
+        }
+
+        cfg->snapshotImageFormat = formatVal;
     }
 
     if (virConfGetValueString(conf, "auto_dump_path", &cfg->autoDumpPath) < 0)
@@ -726,11 +748,11 @@ virQEMUDriverConfigLoadSaveEntry(virQEMUDriverConfig *cfg,
                            autoShutdownTrySave);
             return -1;
         }
-        cfg->autoShutdownTrySave = autoShutdownVal;
+        cfg->autoShutdown.trySave = autoShutdownVal;
     }
 
-    if (cfg->autoShutdownTrySave == VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_ALL ||
-        cfg->autoShutdownTrySave == VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_TRANSIENT) {
+    if (cfg->autoShutdown.trySave == VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_ALL ||
+        cfg->autoShutdown.trySave == VIR_DOMAIN_DRIVER_AUTO_SHUTDOWN_SCOPE_TRANSIENT) {
         virReportError(VIR_ERR_INVALID_ARG, "%s",
                        _("managed save cannot be requested for transient domains"));
         return -1;
@@ -747,7 +769,7 @@ virQEMUDriverConfigLoadSaveEntry(virQEMUDriverConfig *cfg,
                            autoShutdownTryShutdown);
             return -1;
         }
-        cfg->autoShutdownTryShutdown = autoShutdownVal;
+        cfg->autoShutdown.tryShutdown = autoShutdownVal;
     }
 
     if (virConfGetValueString(conf, "auto_shutdown_poweroff", &autoShutdownPoweroff) < 0)
@@ -761,16 +783,16 @@ virQEMUDriverConfigLoadSaveEntry(virQEMUDriverConfig *cfg,
                            autoShutdownPoweroff);
             return -1;
         }
-        cfg->autoShutdownPoweroff = autoShutdownVal;
+        cfg->autoShutdown.poweroff = autoShutdownVal;
     }
 
     if (virConfGetValueUInt(conf, "auto_shutdown_wait",
-                            &cfg->autoShutdownWait) < 0)
+                            &cfg->autoShutdown.waitShutdownSecs) < 0)
         return -1;
-    if (virConfGetValueBool(conf, "auto_shutdown_restore", &cfg->autoShutdownRestore) < 0)
+    if (virConfGetValueBool(conf, "auto_shutdown_restore", &cfg->autoShutdown.autoRestore) < 0)
         return -1;
     if (virConfGetValueBool(conf, "auto_save_bypass_cache",
-                            &cfg->autoSaveBypassCache) < 0)
+                            &cfg->autoShutdown.saveBypassCache) < 0)
         return -1;
 
     return 0;
@@ -1265,6 +1287,31 @@ virQEMUDriverConfigLoadFilesystemEntry(virQEMUDriverConfig *cfg,
 }
 
 
+static int
+virQEMUDriverConfigLoadDeprecatedFeaturesEntry(virQEMUDriverConfig *cfg,
+                                               virConf *conf)
+{
+    g_autofree char *depFeats = NULL;
+
+    if (virConfGetValueString(conf, "default_cpu_deprecated_features", &depFeats) < 0)
+        return -1;
+    if (depFeats) {
+        int val = virQEMUDeprecatedFeaturesTypeFromString(depFeats);
+
+        if (val < 0) {
+            virReportError(VIR_ERR_CONFIG_UNSUPPORTED,
+                           _("Unknown default_cpu_deprecated_features value %1$s"),
+                           depFeats);
+            return -1;
+        }
+
+        cfg->defaultDeprecatedFeatures = val;
+    }
+
+    return 0;
+}
+
+
 int virQEMUDriverConfigLoadFile(virQEMUDriverConfig *cfg,
                                 const char *filename,
                                 bool privileged)
@@ -1345,6 +1392,9 @@ int virQEMUDriverConfigLoadFile(virQEMUDriverConfig *cfg,
     if (virQEMUDriverConfigLoadFilesystemEntry(cfg, conf) < 0)
         return -1;
 
+    if (virQEMUDriverConfigLoadDeprecatedFeaturesEntry(cfg, conf) < 0)
+        return -1;
+
     return 0;
 }
 
@@ -1416,14 +1466,6 @@ virQEMUDriverConfigValidate(virQEMUDriverConfig *cfg)
         return -1;
     }
 
-    if (cfg->vxhsTLSx509certdir &&
-        !virFileExists(cfg->vxhsTLSx509certdir)) {
-        virReportError(VIR_ERR_CONF_SYNTAX,
-                       _("vxhs_tls_x509_cert_dir directory '%1$s' does not exist"),
-                       cfg->vxhsTLSx509certdir);
-        return -1;
-    }
-
     if (cfg->nbdTLSx509certdir &&
         !virFileExists(cfg->nbdTLSx509certdir)) {
         virReportError(VIR_ERR_CONF_SYNTAX,
@@ -1452,11 +1494,26 @@ virQEMUDriverConfigSetDefaults(virQEMUDriverConfig *cfg)
     SET_TLS_SECRET_UUID_DEFAULT(chardev);
     SET_TLS_SECRET_UUID_DEFAULT(migrate);
     SET_TLS_SECRET_UUID_DEFAULT(backup);
-    SET_TLS_SECRET_UUID_DEFAULT(vxhs);
     SET_TLS_SECRET_UUID_DEFAULT(nbd);
 
 #undef SET_TLS_SECRET_UUID_DEFAULT
 
+#define SET_TLS_PRIORITY_DEFAULT(val) \
+    do { \
+        if (!cfg->val## TLSpriority && \
+            cfg->defaultTLSpriority) { \
+            cfg->val## TLSpriority = g_strdup(cfg->defaultTLSpriority); \
+        } \
+    } while (0)
+
+    SET_TLS_PRIORITY_DEFAULT(vnc);
+    SET_TLS_PRIORITY_DEFAULT(chardev);
+    SET_TLS_PRIORITY_DEFAULT(migrate);
+    SET_TLS_PRIORITY_DEFAULT(backup);
+    SET_TLS_PRIORITY_DEFAULT(nbd);
+
+#undef SET_TLS_PRIORITY_DEFAULT
+
     /*
      * If a "SYSCONFDIR" + "pki/libvirt-<val>" exists, then assume someone
      * has created a val specific area to place service specific certificates.
@@ -1481,7 +1538,6 @@ virQEMUDriverConfigSetDefaults(virQEMUDriverConfig *cfg)
     SET_TLS_X509_CERT_DEFAULT(chardev);
     SET_TLS_X509_CERT_DEFAULT(migrate);
     SET_TLS_X509_CERT_DEFAULT(backup);
-    SET_TLS_X509_CERT_DEFAULT(vxhs);
     SET_TLS_X509_CERT_DEFAULT(nbd);
 
 #undef SET_TLS_X509_CERT_DEFAULT
