@@ -130,29 +130,6 @@ qemuHostdevUpdateActiveDomainDevices(virQEMUDriver *driver,
 }
 
 
-bool
-qemuHostdevNeedsVFIO(const virDomainHostdevDef *hostdev)
-{
-    return virHostdevIsVFIODevice(hostdev) ||
-        virHostdevIsMdevDevice(hostdev);
-}
-
-
-bool
-qemuHostdevHostSupportsPassthroughVFIO(void)
-{
-    /* condition 1 - host has IOMMU */
-    if (!virHostHasIOMMU())
-        return false;
-
-    /* condition 2 - /dev/vfio/vfio exists */
-    if (!virFileExists(QEMU_DEV_VFIO))
-        return false;
-
-    return true;
-}
-
-
 int
 qemuHostdevPrepareOneNVMeDisk(virQEMUDriver *driver,
                               const char *name,
