@@ -451,6 +451,11 @@ qemuMonitorJSONGetKVMState(qemuMonitor *mon,
                            bool *present)
     ATTRIBUTE_NONNULL(2) ATTRIBUTE_NONNULL(3);
 
+int
+qemuMonitorJSONGetAccelerators(qemuMonitor *mon,
+                               char **enabled)
+     ATTRIBUTE_NONNULL(2);
+
 int
 qemuMonitorJSONGetObjectTypes(qemuMonitor *mon,
                               char ***types)
@@ -558,6 +563,7 @@ qemuMonitorJSONGetGuestCPU(qemuMonitor *mon,
                            bool qomListGet,
                            const char *cpuQOMPath,
                            qemuMonitorCPUFeatureTranslationCallback translate,
+                           virCPUDefFeatureFilter filter,
                            virCPUData **enabled,
                            virCPUData **disabled);
 
