@@ -19,9 +19,6 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIBVIRT_STORAGE_BACKEND_FS_H
-# define LIBVIRT_STORAGE_BACKEND_FS_H
+#pragma once
 
 int virStorageBackendFsRegister(void);
-
-#endif /* LIBVIRT_STORAGE_BACKEND_FS_H */
