@@ -32,9 +32,6 @@ typedef int (*virQEMUBuildCommandLineJSONArrayFormatFunc)(const char *key,
 int virQEMUBuildCommandLineJSONArrayObjectsStr(const char *key,
                                                virJSONValue *array,
                                                virBuffer *buf);
-int virQEMUBuildCommandLineJSONArrayBitmap(const char *key,
-                                           virJSONValue *array,
-                                           virBuffer *buf);
 int virQEMUBuildCommandLineJSONArrayNumbered(const char *key,
                                              virJSONValue *array,
                                              virBuffer *buf);
