@@ -39,14 +39,6 @@
 
 #define IS_CT(def)  (def->os.type == VIR_DOMAIN_OSTYPE_EXE)
 
-#define vzDomNotFoundError(domain) \
-    do { \
-        char uuidstr[VIR_UUID_STRING_BUFLEN]; \
-        virUUIDFormat(domain->uuid, uuidstr); \
-        virReportError(VIR_ERR_NO_DOMAIN, \
-                       _("no domain with matching uuid '%1$s'"), uuidstr); \
-    } while (0)
-
 #define PARALLELS_DOMAIN_ROUTED_NETWORK_NAME   "host-routed"
 #define VIRTUOZZO_VER_7 ((unsigned long)7000000)
 
