@@ -70,6 +70,7 @@ static int
 fillQemuCaps(virDomainCaps *domCaps,
              const char *name,
              const char *arch,
+             const char *variant,
              const char *machine,
              virQEMUDriverConfig *cfg)
 {
@@ -81,7 +82,7 @@ fillQemuCaps(virDomainCaps *domCaps,
     if (fakeHostCPU(domCaps->arch) < 0)
         return -1;
 
-    path = g_strdup_printf("%s/%s_%s.xml", TEST_QEMU_CAPS_PATH, name, arch);
+    path = g_strdup_printf("%s/%s_%s%s.xml", TEST_QEMU_CAPS_PATH, name, arch, variant);
     if (!(qemuCaps = qemuTestParseCapabilitiesArch(domCaps->arch, path)))
         return -1;
 
@@ -98,10 +99,9 @@ fillQemuCaps(virDomainCaps *domCaps,
     if (!domCaps->machine)
         domCaps->machine = g_strdup(virQEMUCapsGetPreferredMachine(qemuCaps, virtType));
 
-    if (virQEMUCapsFillDomainCaps(qemuCaps, domCaps->arch, domCaps,
-                                  false,
-                                  cfg->firmwares,
-                                  cfg->nfirmwares) < 0)
+    if (virQEMUCapsFillDomainCaps(cfg,
+                                  qemuCaps, domCaps->arch, domCaps,
+                                  false) < 0)
         return -1;
 
     /* The function above tries to query host's VFIO capabilities by calling
@@ -182,6 +182,7 @@ struct testData {
     const char *emulator;
     const char *machine;
     const char *arch;
+    const char *variant;
     virDomainVirtType type;
     enum testCapsType capsType;
     const char *capsName;
@@ -209,8 +210,8 @@ test_virDomainCapsFormat(const void *opaque)
 
     case CAPS_QEMU:
 #if WITH_QEMU
-        if (fillQemuCaps(domCaps, data->capsName, data->arch, data->machine,
-                         data->capsOpaque) < 0)
+        if (fillQemuCaps(domCaps, data->capsName, data->arch, data->variant,
+                         data->machine, data->capsOpaque) < 0)
             return -1;
 #endif
         break;
@@ -259,6 +260,7 @@ doTestQemuInternal(const char *version,
         .emulator = emulator,
         .machine = machine,
         .arch = arch,
+        .variant = variant,
         .type = type,
         .capsType = CAPS_QEMU,
         .capsName = capsName,
@@ -325,13 +327,11 @@ doTestQemu(const char *inputDir G_GNUC_UNUSED,
 
     if (STREQ(variant, "+hvf"))
         hvf = true;
-    else if (STRNEQ(variant, ""))
-        return 0;
 
     if (STREQ(arch, "x86_64")) {
         /* For x86_64 based on the test variant we test:
          *
-         *   '' (default) variant (KVM):
+         *   '' (default) variant or any other non-listed variant:
          *      - KVM with default machine
          *      - KVM with Q35 machine
          *  '+hvf' variant:
@@ -359,7 +359,7 @@ doTestQemu(const char *inputDir G_GNUC_UNUSED,
     } else if (STREQ(arch, "aarch64")) {
         /* For aarch64 based on the test variant we test:
          *
-         *   '' (default) variant (KVM):
+         *   '' (default) variant or any other non-listed variant:
          *      - KVM with default machine
          *      - KVM with virt machine
          *
@@ -380,7 +380,8 @@ doTestQemu(const char *inputDir G_GNUC_UNUSED,
                 ret = -1;
         }
     } else if (STRPREFIX(arch, "riscv") || STRPREFIX(arch, "loongarch64")) {
-        /* For riscv64 or loongarch64 we test two combinations:
+        /* For riscv64 or loongarch64 we test two combinations for any variant:
+         * ('+hvf' is not applicable for this case)
          *
          *   - KVM with virt machine
          *   - TCG with virt machine
@@ -426,6 +427,7 @@ mymain(void)
             .emulator = Emulator, \
             .machine = Machine, \
             .arch = Arch, \
+            .variant = "", \
             .type = Type, \
             .capsType = CapsType, \
         }; \
@@ -440,6 +442,7 @@ mymain(void)
             .emulator = Emulator, \
             .machine = Machine, \
             .arch = Arch, \
+            .variant = "", \
             .type = Type, \
             .capsType = CAPS_LIBXL, \
         }; \
@@ -456,6 +459,7 @@ mymain(void)
             .name = name, \
             .emulator = Emulator, \
             .arch = "x86_64", \
+            .variant = "", \
             .type = Type, \
             .capsType = CAPS_BHYVE, \
             .capsOpaque = BhyveCaps, \
