@@ -22,13 +22,8 @@
 #include "testutils.h"
 
 #include "virkeycode.h"
-#include "virutil.h"
-#include "virerror.h"
-#include "viralloc.h"
 #include "virlog.h"
 
-#include "virlockspace.h"
-
 #define VIR_FROM_THIS VIR_FROM_NONE
 
 VIR_LOG_INIT("tests.keycodetest");
