@@ -46,7 +46,7 @@ findMACsFromJSON(json_object *jobj,
                  size_t *nmacs)
 {
     size_t i;
-    int len;
+    size_t len;
 
     if (!json_object_is_type(jobj, json_type_array)) {
         ERROR("parsed JSON does not contain the leases array");
@@ -101,6 +101,8 @@ findMACsFromJSON(json_object *jobj,
             char *macstr;
 
             macobj = json_object_array_get_idx(macsArray, j);
+            if (!macobj)
+                return -1;
             macstr = strdup(json_object_get_string(macobj));
             if (!macstr)
                 return -1;
