@@ -21,6 +21,7 @@
 #pragma once
 
 #include "vsh.h"
+#include <libxml/xpath.h>
 
 char **
 virshDomainNameCompleter(vshControl *ctl,
@@ -41,6 +42,19 @@ virshDomainDiskTargetCompleter(vshControl *ctl,
                                const vshCmd *cmd,
                                unsigned int flags);
 
+char **
+virshGetThrottleGroupNames(xmlXPathContext *ctxt);
+
+char **
+virshDomainThrottleGroupCompleter(vshControl *ctl,
+                                  const vshCmd *cmd,
+                                  unsigned int flags);
+
+char **
+virshDomainThrottleGroupsCompleter(vshControl *ctl,
+                                   const vshCmd *cmd,
+                                   unsigned int flags);
+
 char **
 virshDomainInterfaceStateCompleter(vshControl *ctl,
                                    const vshCmd *cmd,
