@@ -28,21 +28,21 @@
 #include "virt-host-validate-common.h"
 
 #define MODULE_STATUS(mod, err_msg, err_code) \
-    virHostMsgCheck("BHYVE", _("for %1$s module"), #mod); \
+    virValidateCheck("BHYVE", _("Checking for %1$s module"), #mod); \
     if (mod ## _loaded) { \
-        virHostMsgPass(); \
+        virValidatePass(); \
     } else { \
-        virHostMsgFail(err_code, \
-                       _("%1$s module is not loaded, " err_msg), \
+        virValidateFail(err_code, \
+                        _("%1$s module is not loaded, " err_msg), \
                         #mod); \
         ret = -1; \
     }
 
 #define MODULE_STATUS_FAIL(mod, err_msg) \
-    MODULE_STATUS(mod, err_msg, VIR_HOST_VALIDATE_FAIL)
+    MODULE_STATUS(mod, err_msg, VIR_VALIDATE_FAIL)
 
 #define MODULE_STATUS_WARN(mod, err_msg) \
-    MODULE_STATUS(mod, err_msg, VIR_HOST_VALIDATE_WARN)
+    MODULE_STATUS(mod, err_msg, VIR_VALIDATE_WARN)
 
 
 int virHostValidateBhyve(void)
